/*
 * Eygene Ryabinkin, rea@codelabs.ru.  Copyright 2013.
 *
 * Helper utility to unabbreviate words.  First argument is the
 * abbreviation, next ones -- possible words.  We will output
 * whitespace-separated list of all words whose beginning characters
 * match the abbreviation.
 *
 * Exit codes:
 * 0 -- all OK, single unabbreviated match found;
 * 1 -- ambigious, multiple unabbreviated words found;
 * 2 -- abbreviation was not found;
 * 3 -- bad utility usage, mandatory arguments are missing.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define RETCODE_OK		0
#define RETCODE_AMBIG		1
#define RETCODE_NOTFOUND	2
#define RETCODE_USAGE		3

void
usage(const char *_argv0);

int
main(int argc, char *argv[])
{
	size_t matches;
	char *abbr, **cur, *delim;

	if (argc < 2 || strlen(argv[1]) == 0) {
		usage (argv[0]);
		exit (RETCODE_USAGE);
	}

	abbr = argv[1];

	/* Exact match always wins. */
	cur = &argv[2];
	for (; *cur != NULL; cur++) {
		if (strcmp (abbr, *cur) == 0) {
			printf ("%s\n", abbr);
			return RETCODE_OK;
		}
	}

	/* Try prefix matches. */
	cur = &argv[2];
	delim = "";
	matches = 0;
	for (; *cur != NULL; cur++) {
		if (strncmp (abbr, *cur, strlen(abbr)) == 0) {
			matches++;
			printf ("%s%s", delim, *cur);
			delim = " ";
		}
	}

	if (matches != 0)
		putc ('\n', stdout);

	if (matches == 0)
		return RETCODE_NOTFOUND;
	else if (matches == 1)
		return RETCODE_OK;
	else
		return RETCODE_AMBIG;

	/* NOTREACHED */
}


/**
 * \brief Prints the usage statement.
 *
 * \param argv0 name of the program.
 */
void
usage(const char *argv0)
{
	printf("Usage: %s abbreviation [word1] [word2] ...\n", argv0);
}
