/**
 * \brief BSD's err.h functions.
 *
 * This is the simple implementation of functions
 * from BSD's err.h that we are using.
 */

#include "config.h"

#ifndef HAVE_ERR_H
#include <errno.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "err.h"

/**
 * \brief Prints the formatted string to the standard error,
 * appends the stringified errno and its integer value,
 * appends newline and exits with the specified value.
 *
 * \param eval code to pass to exit()
 * \param fmt printf-like format string.
 */
void
err(int eval, const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	vfprintf(stderr, fmt, ap);
	va_end(ap);

	fprintf(stderr, ": %s: %d\n", strerror(errno), (int)errno);

	exit(eval);
}


/**
 * \brief Prints the formatted string to the standard error,
 * appends the newline and exits with the specified value.
 *
 * \param eval code to pass to exit()
 * \param fmt printf-like format string.
 */
void
errx(int eval, const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	vfprintf(stderr, fmt, ap);
	va_end(ap);

	fputc('\n', stderr);

	exit(eval);
}
#else /* ndef HAVE_ERR_H */
/* Make compilers happy and avoid producing empty object files. */
static const int i = 0;
#endif /* ndef HAVE_ERR_H */
