#!/bin/sh
# Runs all defined tests.

TESTS="
  t.strbuf-read.sh
  t.add-perms.sh
  t.unabbreviate.sh
"

. ./tests.subr

export TMPDIR=`pwd`/tmp
mkdir -p "$TMPDIR" || exit 1

trap '[ -n "$TMPDIR" -a -d "$TMPDIR" ] && rm -rf "$TMPDIR"' 1 2 3 15

TOTAL=0
FAILED=0

n=0
for t in $TESTS; do
	n=$(($n + 1))
	if ! [ -e "$t" ]; then
		echo "Test '$t' does not exist.  Fix me!" >&2
		exit 1
	fi
	if ! [ -x "$t" ]; then
		echo "Test '$t' is not executable.  Fix me!" >&2
		exit 1
	fi
done

i=0
for t in $TESTS; do
	i=$(($i + 1))
	echo -n "[$i/$n] Running ${t}... "
	./"$t"
	if [ "$?" = 0 ]; then
		ok
	else
		failed "test $t was failed."
		FAILED=$(($FAILED + 1))
	fi
	TOTAL=$(($TOTAL + 1))
done

if [ "$FAILED" -eq 0 ]; then
	rm -rf "$TMPDIR"
	echo "Whoo!  No tests were failed."
	exit 0
else
	echo "Failed $FAILED our of $TOTAL tests."
	echo "Results are left in '$TMPDIR' for examination."
	exit 1
fi
