/*
 * Eygene Ryabinkin, rea@codelabs.ru.  Copyright 2012.
 *
 * Test for the strbuf library.
 *
 * It reads the stdin and appends string "METADATA: "
 * to each line that isn't a comment and "# COMMENT: "
 * to each string that starts with '#'.  The result
 * is written to the stdout.
 */

#include <ctype.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>

#include "strbuf.h"
#include "err.h"
#include "sysexits.h"

const char *metadata_tag = "METADATA: ";
const char *comment_tag = "# COMMENT: ";

int main(void)
{
	int in = 0;
	FILE *out = stdout;
	struct strbuf *buf = NULL;

	buf = strbuf_create(80);
	if (buf == NULL)
		err(EX_OSERR, "Unable to allocate string buffer");

	strbuf_errno_clear(buf);
	strbuf_set_fd(buf, in);
	while (1) {
		char *line = strbuf_readline(buf);
		size_t i;

		if (line == NULL) {
			if (strbuf_errno_get(buf) == strbuf_e_eof)
				break;
			else
				errx(EX_OSERR,
				  "Can not read input line: %s",
				  strbuf_errno_to_s(buf));
		}

		for (i = 0; isspace(line[i]); i++);
		fputs((line[i] == '#' ? comment_tag : metadata_tag), out);
		fputs(line, out);
	}

	strbuf_destroy(buf);
	return 0;
}
