#!/bin/sh
#
# We will create the file with comment and non-comment lines,
# pass it to our test binary, will process it through the
# shell script and compare the results.

# Source of random bytes.
RANDOM_SOURCE=/dev/random
# Size of the input file, in KB.
SIZE=1024
# Maximal length of a single line (well, a sort of ;))
LENGTH=512

ME=$(basename "$0")
if [ -z "$ME" ]; then
	echo "Can't determine my own name." >&2
	exit 1
fi

IN=$(mktemp -t "$ME".in) || exit 1
OUT1=$(mktemp -t "$ME".out1) || exit 1
OUT2=$(mktemp -t "$ME".out2) || exit 1

# Creating the file with random commented and uncommented lines.
dd if="$RANDOM_SOURCE" bs=512 count="$((SIZE * 2))" 2>/dev/null | \
openssl base64 | \
  tr 'Bb' '  ' | \
  awk -v LENGTH="$LENGTH" '
function init() {
	N=int(rand() * LENGTH);
	L="";
	SPACE="";
	if (rand() > 0.5) {
		for (i = 0; i < int(rand() * LENGTH); i++) {
			if (rand() < 0.3)
				s=" ";
			else
				s="\t";
			SPACE=SPACE s;
		}
	}
}
function out() {
	if (rand() < 0.5)
		PFX="# "
	else
		PFX=""
	print SPACE PFX L;
	line++;
}
BEGIN { line=0; init(); }
{
	L = L " " $0;
	if (length(L) > N) {
		out();
		init();
	}
}
END { out(); }
' > "$IN"

./t.strbuf-read < "$IN" > "$OUT1"
awk '
/^[[:space:]]*#/	{
	print "# COMMENT: " $0; next;
}
	{ print "METADATA: " $0; next; }
' < "$IN" > "$OUT2"

cmp "$OUT1" "$OUT2" >&2
